function Get-UpdatableFileList {
    param ($LocalManifest, $RemoteManifest)

    if (-not $LocalManifest) {
        $LocalManifest = Read-LocalManifest
    }

    if (-not $RemoteManifest) {
        $RemoteManifest = Read-RemoteManifest
    }

    foreach ($remoteFile in @( $RemoteManifest.FileList ).Where({ $_.Path })) {
        $localFileInfo = [System.IO.FileInfo]$ExecutionContext.SessionState.Path.GetUnresolvedProviderPathFromPSPath("$( $MyInvocation.MyCommand.Module.ModuleBase )/$( $remoteFile.Path )")

        if (-not $localFileInfo.Exists -or (Get-FileHash -Path $localFileInfo.FullName -Algorithm $remoteFile.Algorithm).Hash -ne $remoteFile.Hash) {
            $remoteFile | Add-Member -MemberType NoteProperty -Name LocalFileInfo -Value $localFileInfo

            $remoteFile
        }
    }
}

function Get-LocalManifestPath {
    $ExecutionContext.SessionState.Path.GetUnresolvedProviderPathFromPSPath("$( $MyInvocation.MyCommand.Module.ModuleBase )/Manifest.json")
}

function Read-LocalManifest {
    ConvertFrom-Json -InputObject (Get-Content -Path $( Get-LocalManifestPath ) -Raw -ErrorAction Stop)
}

function Read-RemoteManifest {
    Invoke-RestMethod -Uri "$( [NetAppDocs.UpdateHelper]::GetUpdateUriAndPath($MyInvocation.MyCommand.ModuleName, $MyInvocation.MyCommand.Module.Version).AbsoluteUri )/$( $MyInvocation.MyCommand.ModuleName )_Manifest.json" -Method Get -Verbose:$false
}

function Read-RemoteVersionFile {
    Invoke-RestMethod -Uri "$( [NetAppDocs.UpdateHelper]::GetUpdateUri($MyInvocation.MyCommand.ModuleName).AbsoluteUri )/LatestVersion.json" -Method Get -Verbose:$false
}

function Get-LatestModuleVersion {
    if (-not $RemoteVersionFile) {
        $RemoteVersionFile = Read-RemoteVersionFile
    }

    $RemoteVersionFile.$( $MyInvocation.MyCommand.ModuleName )
}

function Set-DateLastChecked {
    [Diagnostics.CodeAnalysis.SuppressMessageAttribute('PSUseShouldProcessForStateChangingFunctions', '')]
    param ( )

    [NetAppDocs.UpdateHelper]::SetDateLastUpdateChecked()
}

# SIG # Begin signature block
# MIIy0gYJKoZIhvcNAQcCoIIywzCCMr8CAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCB62YtQMFspuQ3a
# VHS7Zzsj2PoMV5jI0BcUBfuRiPQmt6CCFxcwggQ+MIIDJqADAgECAgRKU4woMA0G
# CSqGSIb3DQEBCwUAMIG+MQswCQYDVQQGEwJVUzEWMBQGA1UEChMNRW50cnVzdCwg
# SW5jLjEoMCYGA1UECxMfU2VlIHd3dy5lbnRydXN0Lm5ldC9sZWdhbC10ZXJtczE5
# MDcGA1UECxMwKGMpIDIwMDkgRW50cnVzdCwgSW5jLiAtIGZvciBhdXRob3JpemVk
# IHVzZSBvbmx5MTIwMAYDVQQDEylFbnRydXN0IFJvb3QgQ2VydGlmaWNhdGlvbiBB
# dXRob3JpdHkgLSBHMjAeFw0wOTA3MDcxNzI1NTRaFw0zMDEyMDcxNzU1NTRaMIG+
# MQswCQYDVQQGEwJVUzEWMBQGA1UEChMNRW50cnVzdCwgSW5jLjEoMCYGA1UECxMf
# U2VlIHd3dy5lbnRydXN0Lm5ldC9sZWdhbC10ZXJtczE5MDcGA1UECxMwKGMpIDIw
# MDkgRW50cnVzdCwgSW5jLiAtIGZvciBhdXRob3JpemVkIHVzZSBvbmx5MTIwMAYD
# VQQDEylFbnRydXN0IFJvb3QgQ2VydGlmaWNhdGlvbiBBdXRob3JpdHkgLSBHMjCC
# ASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALqEtnLbngxr4pnpMAGnduoy
# uJVBGsnaYU5Ycs/+9oJ5v3NhBgqlJ9izX9NFThxy1k4y8nKKD/eDGdBqgIAARR6w
# x+eavxJXJxyjaC8Kh71qaw5eZfMcd9XUhY1wIbSzMueLotWGOQKxuNJHzuTJScQ7
# p977VH1XvvDobsJ5sjoLVeJQmBYyE1wveFbBwpSz8lrkJ5qfJNfG7NCbJYLjzMLE
# RcWMl3oGayoRn6kKbkg7b9vUERlC948Hv/VTX5w+9Bcs5mmsTjJMYnfqt+jluzS8
# GYuunFHnt361U7EzIuVtz3A8Gvrim2e2g/SNpa9iTE3gWKxkNBID+LaNlGMkpHEC
# AwEAAaNCMEAwDgYDVR0PAQH/BAQDAgEGMA8GA1UdEwEB/wQFMAMBAf8wHQYDVR0O
# BBYEFGpyJnrQHu995ztpUdRsjZ+QEmarMA0GCSqGSIb3DQEBCwUAA4IBAQB5nx2W
# xrZ5PyKNh9OHAwRgamuaLlmJcxGsQ9H1E/+NOSvA8r1PcIypL+oXxAtUntQblpgz
# PKitYqIAdqtZaW4GHX7EuUSNmK8S1GHbChlGR/Pr92PBQAVApdK39LWaNr+piHaI
# BFUEK5yHfxo3PH4tpRrY1Ileyr2sPWzYba/V83YPzTuIOCKdbJOaxD2/ghtlP6YP
# Xar85bIVyrWtxrw90ITo6gZysE05Mni/PhGcC6SdmiHz8JsLMHjbwdyHQ/68Y5rK
# xcIcyceN/zsSWAjmtj3seixO+4OWzgw8aYdUc6RzwpP/URCsFVQB2PwFsYmhf3SD
# mknX3E57ikhvi0X2MIIF3zCCBMegAwIBAgIQTkDkN1Tt5owAAAAAUdOUfzANBgkq
# hkiG9w0BAQsFADCBvjELMAkGA1UEBhMCVVMxFjAUBgNVBAoTDUVudHJ1c3QsIElu
# Yy4xKDAmBgNVBAsTH1NlZSB3d3cuZW50cnVzdC5uZXQvbGVnYWwtdGVybXMxOTA3
# BgNVBAsTMChjKSAyMDA5IEVudHJ1c3QsIEluYy4gLSBmb3IgYXV0aG9yaXplZCB1
# c2Ugb25seTEyMDAGA1UEAxMpRW50cnVzdCBSb290IENlcnRpZmljYXRpb24gQXV0
# aG9yaXR5IC0gRzIwHhcNMjEwNTA3MTU0MzQ1WhcNMzAxMTA3MTYxMzQ1WjBpMQsw
# CQYDVQQGEwJVUzEWMBQGA1UECgwNRW50cnVzdCwgSW5jLjFCMEAGA1UEAww5RW50
# cnVzdCBDb2RlIFNpZ25pbmcgUm9vdCBDZXJ0aWZpY2F0aW9uIEF1dGhvcml0eSAt
# IENTQlIxMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAp4GP9xRFtmJD
# 8tiu0yVeSE9Rv8V9n1AcNdHWfmEqlBltJ0akphpd91RRaoAixqhmdU1Ug8leaBur
# 9ltksK2tIL1U70ZrbQLnRa519o6KuTIui7h3HFJNeYhfpToYyVAslyctv9oAfWN/
# 7zLsRodj25qfw1ohNnv5m9XKoG5yLPzh8Z5wTQhWFW+Qq/tIurnXwYJ4hWUuf7XJ
# wOIUtzcRQQbiiuCo9uV+tngFAcNg7U8HQS4KE0njkJt/3b36rL9kUdFcm7T1XOdc
# /zubpaAa130JssK3/24cvMh95ukr/HKzFOlKVRKEnEQldR32KvBPpSA9aCXrYZd8
# D+W2PfOuw8ERvBuOzOBHMF5CAIZx41isBsplH3uUpktXZwx+Xq14Z1tV417rx9js
# TG6Gy/Pc+J+HqnJYEg99pvj4Qjk7PCzkMk1JjODhAMI4oJz6hD5B3G5WrsYaW/Rn
# aAUBzRu/roe8nVP2Lui2a+SZ3sVPh1io0mUeyB/Vcm7uWRxXOwlyndfKt5DGzXtF
# kpFCA0x9P8ryqrjCDobzEJ9GLqRmhmhaaBhwKTgRgGBrikOjc2zjs2s3/+adZwGS
# ht8vSNH7UGDVXP4h0wFCY/7vcLQXwI+o7tPBS18S6v39Lg6HRGDjqfTCGKPj/c4M
# hCIN86d42pPz2zjPuS8zxv8HPF6+RdMCAwEAAaOCASswggEnMA4GA1UdDwEB/wQE
# AwIBhjASBgNVHRMBAf8ECDAGAQH/AgEBMB0GA1UdJQQWMBQGCCsGAQUFBwMDBggr
# BgEFBQcDCDA7BgNVHSAENDAyMDAGBFUdIAAwKDAmBggrBgEFBQcCARYaaHR0cDov
# L3d3dy5lbnRydXN0Lm5ldC9ycGEwMwYIKwYBBQUHAQEEJzAlMCMGCCsGAQUFBzAB
# hhdodHRwOi8vb2NzcC5lbnRydXN0Lm5ldDAwBgNVHR8EKTAnMCWgI6Ahhh9odHRw
# Oi8vY3JsLmVudHJ1c3QubmV0L2cyY2EuY3JsMB0GA1UdDgQWBBSCutY9l86fz3Ho
# kjev/bO1aTVXzzAfBgNVHSMEGDAWgBRqciZ60B7vfec7aVHUbI2fkBJmqzANBgkq
# hkiG9w0BAQsFAAOCAQEAH15BBLaDcCRTLFVzHWU6wOy0ewSYXlk4EwmkWZRCXlC/
# T2xuJSCQk1hADfUZtGLuJF7CAVgVAh0QCW+o1PuSfjc4Pi8UfY8dQzZks2YTXxTM
# pXH3WyFLxpe+3JX8cH0RHNMh3dAkOSnF/goapc97ee46b97cv+kR3RaDCNMsjX9N
# qBR5LwVhUjjrYPMUaH3LsoqtwJRc5CYOLIrdRsPO5FZRxVbjhbhNm0VyiwfxivtJ
# uF/R8paBXWlSJPEII9LWIw/ri9d+i8GTa/rxYntY6VCbl24XiA3hxkOY14FhtoWd
# R+yxnq4/IDtDndiiHODUfAjCr3YG+GJmerb3+sivNTCCBmcwggRPoAMCAQICEEbM
# 41QNEgkq80rzt39+/oswDQYJKoZIhvcNAQELBQAwYzELMAkGA1UEBhMCVVMxFjAU
# BgNVBAoTDUVudHJ1c3QsIEluYy4xPDA6BgNVBAMTM0VudHJ1c3QgRXh0ZW5kZWQg
# VmFsaWRhdGlvbiBDb2RlIFNpZ25pbmcgQ0EgLSBFVkNTMjAeFw0yNDEwMjMxNTIy
# MTRaFw0yNTExMDkxNTIyMTNaMIHCMQswCQYDVQQGEwJVUzETMBEGA1UECBMKQ2Fs
# aWZvcm5pYTERMA8GA1UEBxMIU2FuIEpvc2UxEzARBgsrBgEEAYI3PAIBAxMCVVMx
# GTAXBgsrBgEEAYI3PAIBAhMIRGVsYXdhcmUxFDASBgNVBAoTC05ldEFwcCwgSW5j
# MR0wGwYDVQQPExRQcml2YXRlIE9yZ2FuaXphdGlvbjEQMA4GA1UEBRMHMzQ1Mjc0
# MzEUMBIGA1UEAxMLTmV0QXBwLCBJbmMwggGiMA0GCSqGSIb3DQEBAQUAA4IBjwAw
# ggGKAoIBgQCIHyusYBqN6d8MjDVGb9yKy/jxOJi5Ry9vtMsEpSe0eX1NwlzjdPpo
# R+kSTTj0HXwjn48v4UtO3lOWVVdqDuAuECTvG+n31c1RmaB4qS0qg9VEDsUP0/gr
# R4GlmEnGRIeDNWnRIV4oHGTqA1NjNU3esZYLQSV9j5DSzh0W+vyq10stDZiLBNai
# KoBzi5fs+C7QWW+xd+fSFV3Z+zIfE/jHFa4ZKP0n8Bva/5XKZSg6XVBN09oY/EF2
# 67wlz2018jiSwKZi++kCqTIpp9j7dKP5x+0/bK4GlGeivT/NObhjDN8e0Iu5rC2L
# tCalpr5CBMzjKmwfV8mVd9L/qPKk8QZxBdBrUpA1qHDCHbd9BRcd2zT8doIbM0vT
# dHnT9pRPZYws7BfT33KMoV7nShbrNViWhkP3i3UkQv7W9RptiZwfEDpt4Lxn0Uw8
# Zf94fbwMQaV3A28ItUbueLN23+k41N0jqdFTbpCaqQpUT/NxlRHECtn0Lp6kjZTy
# wKF7FqH+jpcCAwEAAaOCATUwggExMAwGA1UdEwEB/wQCMAAwHQYDVR0OBBYEFGzw
# 5EcKP/wp/cuZ0BIs8j6slZQcMB8GA1UdIwQYMBaAFM6JT4JRqhWihGLKMSNh0mH7
# +P54MA4GA1UdDwEB/wQEAwIHgDATBgNVHSUEDDAKBggrBgEFBQcDAzBnBggrBgEF
# BQcBAQRbMFkwIwYIKwYBBQUHMAGGF2h0dHA6Ly9vY3NwLmVudHJ1c3QubmV0MDIG
# CCsGAQUFBzAChiZodHRwOi8vYWlhLmVudHJ1c3QubmV0L2V2Y3MyLWNoYWluLnA3
# YzAxBgNVHR8EKjAoMCagJKAihiBodHRwOi8vY3JsLmVudHJ1c3QubmV0L2V2Y3My
# LmNybDAgBgNVHSAEGTAXMAcGBWeBDAEDMAwGCmCGSAGG+mwKAQIwDQYJKoZIhvcN
# AQELBQADggIBADAwfASY7H1rvIVgDB4LCw7V6xYShLM1XBV0YV8mgn50EVUgkXRr
# qwdn9JgVJvPU6jQ30ab9bb2505N/e1hWQN+Skw21Kbixw3mJ2lZNjY9CvwPUAc4B
# 9xXFEl/w7w1GuATgHO77YCpe0QTbYpbuSTXA0YBs1LlzmuoMxCD+E82srnED8Crg
# m4IHe71kpqqbsIYDnxujU+w/+/CAijPCuxXD2Ff1D7Ms97n9OFvLZHU2e+7xTP66
# RFXF81uCNcLYZSAMiXpjFCiXz74yNHtqZYecnNKvA3hUnvE0BH2IbJFpFiwQO9H2
# rSxdf6qTJANWvCTm7AkDMPhCneufSIFeGHyINH5sKNc+MgsNawZwy2Bfld2YE+ii
# +RyoUgQvl+OZu58dcPYvbgSkc+nE7Xlq/nzE4qNB83ZUuo4MQuGgZ1ZdROSgO6BD
# lCDa1Mr+viR84DtT6dwMYDf0PYWe0LoDYBVLRknZHpSNCMULURCTENBJdJo1mrOn
# hmmm5ZJ3Hg/CmyrujK67YvNFUsQnpLKYEut7ntmJM5ptEPm7Ql5zzaOp3o68a/Q6
# 0+s6p4NwZQYo4ekHk+DM4oaPiv8K+dEPxvppQCSoSPG0S59A8oFBXzoaidOTC06j
# xfGFkPFtOEIO269lK0NCIgr2lJvlUdlUPSnM2eWkEkslz42ShJgON0SaMIIGgzCC
# BGugAwIBAgIQNa+3e500H2r8j4RGqzE1KzANBgkqhkiG9w0BAQ0FADBpMQswCQYD
# VQQGEwJVUzEWMBQGA1UECgwNRW50cnVzdCwgSW5jLjFCMEAGA1UEAww5RW50cnVz
# dCBDb2RlIFNpZ25pbmcgUm9vdCBDZXJ0aWZpY2F0aW9uIEF1dGhvcml0eSAtIENT
# QlIxMB4XDTIxMDUwNzE5MTk1MloXDTQwMTIyOTIzNTkwMFowYzELMAkGA1UEBhMC
# VVMxFjAUBgNVBAoTDUVudHJ1c3QsIEluYy4xPDA6BgNVBAMTM0VudHJ1c3QgRXh0
# ZW5kZWQgVmFsaWRhdGlvbiBDb2RlIFNpZ25pbmcgQ0EgLSBFVkNTMjCCAiIwDQYJ
# KoZIhvcNAQEBBQADggIPADCCAgoCggIBAL69pznJpX3sXWXx9Cuph9DnrRrFGjsY
# zuGhUY1y+s5YH1y4JEIPRtUxl9BKTeObMMm6l6ic/kU2zyeA53u4bsEkt9+ndNyF
# 8qMkWEXMlJQ7AuvEjXxG9VxmguOkwdMfrG4MUyMO1Dr62kLxg1RfNTJW8rV4m1cA
# SB6pYWEnDnMDQ7bWcJL71IWaMMaz5ppeS+8dKthmqxZG/wvYD6aJSgJRV0E8QThO
# l8dRMm1njmahXk2fNSKv1Wq3f0BfaDXMafrxBfDqhabqMoXLwcHKg2lFSQbcCWy6
# SWUZjPm3NyeMZJ414+Xs5wegnahyvG+FOiymFk49nM8I5oL1RH0owL2JrWwv3C94
# eRHXHHBL3Z0ITF4u+o29p91j9n/wUjGEbjrY2VyFRJ5jBmnQhlh4iZuHu1gcpChs
# xv5pCpwerBFgal7JaWUu7UMtafF4tzstNfKqT+If4wFvkEaq1agNBFegtKzjbb2d
# GyiAJ0bH2qpnlfHRh3vHyCXphAyPiTbSvjPhhcAz1aA8GYuvOPLlk4C/xsOre5PE
# PZ257kV2wNRobzBePLQ2+ddFQuASBoDbpSH85wV6KI20jmB798i1SkesFGaXoFpp
# cjFXa1OEzWG6cwcVcDt7AfynP4wtPYeM+wjX5S8Xg36Cq08J8inhflV3ZZQFHVnU
# Ct2TfuMUXeK7AgMBAAGjggErMIIBJzASBgNVHRMBAf8ECDAGAQH/AgEAMB0GA1Ud
# DgQWBBTOiU+CUaoVooRiyjEjYdJh+/j+eDAfBgNVHSMEGDAWgBSCutY9l86fz3Ho
# kjev/bO1aTVXzzAzBggrBgEFBQcBAQQnMCUwIwYIKwYBBQUHMAGGF2h0dHA6Ly9v
# Y3NwLmVudHJ1c3QubmV0MDEGA1UdHwQqMCgwJqAkoCKGIGh0dHA6Ly9jcmwuZW50
# cnVzdC5uZXQvY3NicjEuY3JsMA4GA1UdDwEB/wQEAwIBhjATBgNVHSUEDDAKBggr
# BgEFBQcDAzBEBgNVHSAEPTA7MDAGBFUdIAAwKDAmBggrBgEFBQcCARYaaHR0cDov
# L3d3dy5lbnRydXN0Lm5ldC9ycGEwBwYFZ4EMAQMwDQYJKoZIhvcNAQENBQADggIB
# AD4AVLgq849mr2EWxFiTZPRBi2RVjRs1M6GbkdirRsqrX7y+fnDk0tcHqJYH14bR
# VwoI0NB4Tfgq37IE85rh13zwwQB6wUCh34qMt8u0HQFh8piapt24gwXKqSwW3Jwt
# Dv6nl+RQqZeVwUsqjFHjxALga3w1TVO8S5QTi1MYFl6mCqe4NMFssess5DF9DCzG
# fOGkVugtdtWyE3XqgwCuAHfGb6k97mMUgVAW/FtPEhkOWw+N6kvOBkyJS64gzI5H
# pnXWZe4vMOhdNI8fgk1cQqbyFExQIJwJonQkXDnYiTKFPK+M5Wqe5gQ6pRP/qh3N
# R0suAgW0ao/rhU+B7wrbfZ8pj6XCP1I4UkGVO7w+W1QwQiMJY95QjYk1RfqruA+P
# oq17ehGT8Y8ohHtoeUdq6GQpTR/0HS9tHsiUhjzTWpl6a3yrNfcrOUtPuT8Wku8p
# jI2rrAEazHFEOctAPiASzghw40f+3IDXCADRC2rqIbV5ZhfpaqpW3c0VeLEDwBSt
# PkcYde0KU0syk83/gLGQ1hPl5EF4Iu1BguUO37DOlSFF5osB0xn39CtVrNlWc2MQ
# 4LigbctUlpigmSFRBqqmDDorY8t52kO50hLM3o9VeukJ8+Ka0yXBezaS2uDlUmfN
# 4+ZUCqWd1HOj0y9dBmSFA3d/YNjCvHTJlZFot7d+YRl1MYIbETCCGw0CAQEwdzBj
# MQswCQYDVQQGEwJVUzEWMBQGA1UEChMNRW50cnVzdCwgSW5jLjE8MDoGA1UEAxMz
# RW50cnVzdCBFeHRlbmRlZCBWYWxpZGF0aW9uIENvZGUgU2lnbmluZyBDQSAtIEVW
# Q1MyAhBGzONUDRIJKvNK87d/fv6LMA0GCWCGSAFlAwQCAQUAoIGEMBgGCisGAQQB
# gjcCAQwxCjAIoAKAAKECgAAwGQYJKoZIhvcNAQkDMQwGCisGAQQBgjcCAQQwHAYK
# KwYBBAGCNwIBCzEOMAwGCisGAQQBgjcCARUwLwYJKoZIhvcNAQkEMSIEIIfVdrZu
# UU0fSyCs2wVgq7k8qst179GvU5O/vJVfscV+MA0GCSqGSIb3DQEBAQUABIIBgGhc
# fAevyXtmCWozIJvEu11q8B1ilvr3IBcSOX/jq8dZCj+FFYajCQX1COcf5GVYS3Hq
# BbbydqZjny3eYfddB/ijBilDPEMNVU8vfrXL2EbcCZxLIS3J9jt5TAv6yoVTS8Hd
# K2IKkreAEmrUQ/wCGtkzWM9ekr8QH6aogkh5idKWI4ZngPYhGlsarfiCI/ILhQnV
# JfdZTqggIz1qYylTaM6+5kKFu+g558mEtg2X9j6vRfHZ2PeFPF+Vnsre56I+oWgN
# ILIxjoBzlNl2rbNXEoZ7KGxC/TvjnnTXf/zePweWO1q6m3Oqk0ZucYS0fDIT1ono
# szoJGw5NZ9fRAnRvKrz0kVpXcpQ9NWibnrbWZBMSLsq/oMliGzJGhe4l7h6dzy8G
# lYztM7CaLAGJFX8/BPbZlwaKDO8vAQGI8htA7+K61vWoTCHGEIqL3igRy1HnNMK2
# 8lDJsshiD1vSqPBITKthjIlBRkh3Nb3kiVyyfxIHSGHXAjvGc0dkhGXJkc4uQKGC
# GGQwghhgBgorBgEEAYI3AwMBMYIYUDCCGEwGCSqGSIb3DQEHAqCCGD0wghg5AgED
# MQ0wCwYJYIZIAWUDBAIDMIH0BgsqhkiG9w0BCRABBKCB5ASB4TCB3gIBAQYKYIZI
# AYb6bAoDBTAxMA0GCWCGSAFlAwQCAQUABCA0B7omnQMBBPDHJNhfh5OrSjN0H6bX
# JXmu8qt+F+FCuQIJAIeqdT2MTVimGA8yMDI1MDEwOTAzMDYyOVowAwIBAaB5pHcw
# dTELMAkGA1UEBhMCQ0ExEDAOBgNVBAgTB09udGFyaW8xDzANBgNVBAcTBk90dGF3
# YTEWMBQGA1UEChMNRW50cnVzdCwgSW5jLjErMCkGA1UEAxMiRW50cnVzdCBUaW1l
# c3RhbXAgQXV0aG9yaXR5IC0gVFNBMqCCEw4wggXfMIIEx6ADAgECAhBOQOQ3VO3m
# jAAAAABR05R/MA0GCSqGSIb3DQEBCwUAMIG+MQswCQYDVQQGEwJVUzEWMBQGA1UE
# ChMNRW50cnVzdCwgSW5jLjEoMCYGA1UECxMfU2VlIHd3dy5lbnRydXN0Lm5ldC9s
# ZWdhbC10ZXJtczE5MDcGA1UECxMwKGMpIDIwMDkgRW50cnVzdCwgSW5jLiAtIGZv
# ciBhdXRob3JpemVkIHVzZSBvbmx5MTIwMAYDVQQDEylFbnRydXN0IFJvb3QgQ2Vy
# dGlmaWNhdGlvbiBBdXRob3JpdHkgLSBHMjAeFw0yMTA1MDcxNTQzNDVaFw0zMDEx
# MDcxNjEzNDVaMGkxCzAJBgNVBAYTAlVTMRYwFAYDVQQKDA1FbnRydXN0LCBJbmMu
# MUIwQAYDVQQDDDlFbnRydXN0IENvZGUgU2lnbmluZyBSb290IENlcnRpZmljYXRp
# b24gQXV0aG9yaXR5IC0gQ1NCUjEwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIK
# AoICAQCngY/3FEW2YkPy2K7TJV5IT1G/xX2fUBw10dZ+YSqUGW0nRqSmGl33VFFq
# gCLGqGZ1TVSDyV5oG6v2W2Swra0gvVTvRmttAudFrnX2joq5Mi6LuHccUk15iF+l
# OhjJUCyXJy2/2gB9Y3/vMuxGh2Pbmp/DWiE2e/mb1cqgbnIs/OHxnnBNCFYVb5Cr
# +0i6udfBgniFZS5/tcnA4hS3NxFBBuKK4Kj25X62eAUBw2DtTwdBLgoTSeOQm3/d
# vfqsv2RR0VybtPVc51z/O5uloBrXfQmywrf/bhy8yH3m6Sv8crMU6UpVEoScRCV1
# HfYq8E+lID1oJethl3wP5bY9867DwRG8G47M4EcwXkIAhnHjWKwGymUfe5SmS1dn
# DH5erXhnW1XjXuvH2OxMbobL89z4n4eqclgSD32m+PhCOTs8LOQyTUmM4OEAwjig
# nPqEPkHcblauxhpb9GdoBQHNG7+uh7ydU/Yu6LZr5JnexU+HWKjSZR7IH9Vybu5Z
# HFc7CXKd18q3kMbNe0WSkUIDTH0/yvKquMIOhvMQn0YupGaGaFpoGHApOBGAYGuK
# Q6NzbOOzazf/5p1nAZKG3y9I0ftQYNVc/iHTAUJj/u9wtBfAj6ju08FLXxLq/f0u
# DodEYOOp9MIYo+P9zgyEIg3zp3jak/PbOM+5LzPG/wc8Xr5F0wIDAQABo4IBKzCC
# AScwDgYDVR0PAQH/BAQDAgGGMBIGA1UdEwEB/wQIMAYBAf8CAQEwHQYDVR0lBBYw
# FAYIKwYBBQUHAwMGCCsGAQUFBwMIMDsGA1UdIAQ0MDIwMAYEVR0gADAoMCYGCCsG
# AQUFBwIBFhpodHRwOi8vd3d3LmVudHJ1c3QubmV0L3JwYTAzBggrBgEFBQcBAQQn
# MCUwIwYIKwYBBQUHMAGGF2h0dHA6Ly9vY3NwLmVudHJ1c3QubmV0MDAGA1UdHwQp
# MCcwJaAjoCGGH2h0dHA6Ly9jcmwuZW50cnVzdC5uZXQvZzJjYS5jcmwwHQYDVR0O
# BBYEFIK61j2Xzp/PceiSN6/9s7VpNVfPMB8GA1UdIwQYMBaAFGpyJnrQHu995ztp
# UdRsjZ+QEmarMA0GCSqGSIb3DQEBCwUAA4IBAQAfXkEEtoNwJFMsVXMdZTrA7LR7
# BJheWTgTCaRZlEJeUL9PbG4lIJCTWEAN9Rm0Yu4kXsIBWBUCHRAJb6jU+5J+Nzg+
# LxR9jx1DNmSzZhNfFMylcfdbIUvGl77clfxwfREc0yHd0CQ5KcX+Chqlz3t57jpv
# 3ty/6RHdFoMI0yyNf02oFHkvBWFSOOtg8xRofcuyiq3AlFzkJg4sit1Gw87kVlHF
# VuOFuE2bRXKLB/GK+0m4X9HyloFdaVIk8Qgj0tYjD+uL136LwZNr+vFie1jpUJuX
# bheIDeHGQ5jXgWG2hZ1H7LGerj8gO0Od2KIc4NR8CMKvdgb4YmZ6tvf6yK81MIIG
# bzCCBFegAwIBAgIQJbwr8ynKEH8eqbqIhdSdOzANBgkqhkiG9w0BAQ0FADBpMQsw
# CQYDVQQGEwJVUzEWMBQGA1UECgwNRW50cnVzdCwgSW5jLjFCMEAGA1UEAww5RW50
# cnVzdCBDb2RlIFNpZ25pbmcgUm9vdCBDZXJ0aWZpY2F0aW9uIEF1dGhvcml0eSAt
# IENTQlIxMB4XDTIxMDUwNzE5MjIxNFoXDTQwMTIyOTIzNTkwMFowTjELMAkGA1UE
# BhMCVVMxFjAUBgNVBAoTDUVudHJ1c3QsIEluYy4xJzAlBgNVBAMTHkVudHJ1c3Qg
# VGltZSBTdGFtcGluZyBDQSAtIFRTMjCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCC
# AgoCggIBALUDKga2hE80zJ4xvuqOxntuICQPA9e9gTYz5m/SPrvEnqqgzGZdQmA0
# UeItYYO6PJ5ouEvDZo6l3iu6my1Bpd7Qy1cFLYjZwEaIbTw1DRmQrLgMGfBMxdtF
# W9w7wryNRADgOP//XcjPCJo91LLre5XDxKUA4GIBZFlfjON7i6n5RbfGsKIKN0O4
# RoGrhn5/L97wX+vNIMylLTHjqC6Zm+B43fTbXYJjfTA5iH4kBuZ8YIR4yFwp5ZXL
# 9XtPz1jckM+nonsUVMTgN5gwwZu2rpwp9mslQ+cSaj4Zi77A54HXSjAIfnyN3zzz
# SJMh3oGDap0APtdgutGzYgiW6bZJADj0XHYN2ndqPaCV3h6hzFl6Xp/P6XZdQPK1
# FbVgaCzzWskjg9j1GmtpKKS21K5iBt4mRb3e6VZ3qtxksEHNzBPxXXF0spQIS08y
# bn5wuHfp1TI3wnreQhLocRzi2GK/qmtBhgZb5mm+Jgn0l8L+TPSAcoRu297FB6mO
# FaJt4RvgCQ/1oAegu8R3cwk8B5ONAbUSZy1NGbW4xckQq3DPQv+lJx3WEtbkGERg
# +zldhLtmtVMSnQMUgmUptOxJcv2zQ+XDAikkuh/4uL5do7cuqfzPYtn6l8QTeONV
# uVp6hOv/u89piMC2+YtghUEQUMcFENJedp0+Nez2T4r5Ens/rws3AgMBAAGjggEs
# MIIBKDASBgNVHRMBAf8ECDAGAQH/AgEAMB0GA1UdDgQWBBQmD/DESAgbzd2R9VRU
# trOz/JnxCDAfBgNVHSMEGDAWgBSCutY9l86fz3Hokjev/bO1aTVXzzAzBggrBgEF
# BQcBAQQnMCUwIwYIKwYBBQUHMAGGF2h0dHA6Ly9vY3NwLmVudHJ1c3QubmV0MDEG
# A1UdHwQqMCgwJqAkoCKGIGh0dHA6Ly9jcmwuZW50cnVzdC5uZXQvY3NicjEuY3Js
# MA4GA1UdDwEB/wQEAwIBhjATBgNVHSUEDDAKBggrBgEFBQcDCDBFBgNVHSAEPjA8
# MDAGBFUdIAAwKDAmBggrBgEFBQcCARYaaHR0cDovL3d3dy5lbnRydXN0Lm5ldC9y
# cGEwCAYGZ4EMAQQCMA0GCSqGSIb3DQEBDQUAA4ICAQB2PUZohV8JwM7J+Me4136n
# XDsLRnPOIlOLOPYRunfEwochjyfZDJXr6EvlXNeQFW+oKiyKauAiETR5+r2Wech2
# Fs2xROpxUQ+bVckYfNWCeZzzpreTqQU4cgIGl6Gosnl+Xgjibmx5mqiHlM5/j1U2
# QA+fP1HVZr57q4bmboe6TmNdsdiOH8tnww1w2nrrk7IUhNI+fZM/Fgw2oFx5AJ8L
# buWEKtiIwW0Etzfzkppw4DsD/c27J4LOL/yN5LLKvvglhcbtdMg9NV84CT15T+sb
# 4EFepXSBP1EVwPhJiI+6uwXUrUWCM3nBJY1fVD2R5LifF5gAXa0o5U9fG/v4VLWl
# xCT88HY7+A1ezEewyqq7blHfU7VJGvFgh7f5/WkGdV9z1hGQ8oBYjuXDDwOYjART
# symH3z/3sOlMV4EkRHlo/hs2B9ZlPexv1sK1qmF8Zgbs0uVpgPhxki5c4hFGGEVL
# 1voFZO+73gbKQyW9343JAXRhiNvwx6Y94wxxvH9L58jgbuDagPkAnsBrJdWjulwr
# /sRgIBRKByMx5RrLkUSymntD8VuYtSFLuDE7IlTueWH3mpQbZicqxt/hZV3vcTnm
# UCX9hzS5rl18JzvnZZP4KISxb4aTLJOTtnCvoe7IpGGphDv7Crf4uG0m7kdO9V4F
# +pwPEX3Xy5GuQyD3FVljvDCCBrQwggScoAMCAQICEFtwJsyW9ngau4X2EfVtu24w
# DQYJKoZIhvcNAQENBQAwTjELMAkGA1UEBhMCVVMxFjAUBgNVBAoTDUVudHJ1c3Qs
# IEluYy4xJzAlBgNVBAMTHkVudHJ1c3QgVGltZSBTdGFtcGluZyBDQSAtIFRTMjAe
# Fw0yNDAxMTkxNjQ3NDdaFw0zNTA0MTgwMDAwMDBaMHUxCzAJBgNVBAYTAkNBMRAw
# DgYDVQQIEwdPbnRhcmlvMQ8wDQYDVQQHEwZPdHRhd2ExFjAUBgNVBAoTDUVudHJ1
# c3QsIEluYy4xKzApBgNVBAMTIkVudHJ1c3QgVGltZXN0YW1wIEF1dGhvcml0eSAt
# IFRTQTIwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCqhgQ4Xo9ov4P1
# Wv1Um8V9OnWdxKctT23p0AUfUeMzuy9fOrGWVIrpCHw0rYmDVaSfAswjC9gbekCk
# zJ9C6hN/fLjgt0oCBeKDSQRvBobNc0Gpg9SYZ/r0Uhl640pZKIdWF11I8YaRC7gi
# ZNtB+V1UtTWkbjjcCA0aVhhAw36YPEIzhA3FpWFRziBtTwDLQvCodRvbRv4p3Bue
# 1/gYBVF2MJt0vZUfGVNlFUcsVmNr6bpIrAo4tsFy/SAKo3Qaawd/0d2sF861HMd6
# iQzsbRwwjQXwrz2XzDW0tQUDZrqedvw52sia1hIS5EHChSJA8Mu6iOnSh8KrxjQ7
# 5asNAAYOBrWLe9ELIto8qMlWe/A1BJbqWUaMj9SgtamDsM6E+0tE5UGoFvOv2tGg
# J3DfB+83866RztQhf4aY3F7uj8DaR9tpyhC5kZWAFWPxKxrClqEfwvc81PZ9JAcl
# qFSUbwpV29skQ24uO6J7Sbu11hiP2QSzvurHtWSaS85SYR4rBR5jN0adscnVXoek
# 6tc0siFCF7g6KDpepe0+/TcXf2Mg8nvWX8rzFD/hzv+Kd5RmbYnB4Ox/BHA4ZCf1
# pxd9TcoMgRvF5fE2xXqufSmkRzU4+g30UwMpBfxvoYvJzfG4iEDT0tueJTGt1+Za
# 2AS0hLsERmFm/10y3vzTPnxOGO9+3wIDAQABo4IBZTCCAWEwDAYDVR0TAQH/BAIw
# ADAdBgNVHQ4EFgQU9XYa+BCYkqEbd6kALPGVYgILeScwHwYDVR0jBBgwFoAUJg/w
# xEgIG83dkfVUVLazs/yZ8QgwaAYIKwYBBQUHAQEEXDBaMCMGCCsGAQUFBzABhhdo
# dHRwOi8vb2NzcC5lbnRydXN0Lm5ldDAzBggrBgEFBQcwAoYnaHR0cDovL2FpYS5l
# bnRydXN0Lm5ldC90czItY2hhaW4yNTYucDdjMDEGA1UdHwQqMCgwJqAkoCKGIGh0
# dHA6Ly9jcmwuZW50cnVzdC5uZXQvdHMyY2EuY3JsMA4GA1UdDwEB/wQEAwIHgDAW
# BgNVHSUBAf8EDDAKBggrBgEFBQcDCDBMBgNVHSAERTBDMDcGCmCGSAGG+mwKAQcw
# KTAnBggrBgEFBQcCARYbaHR0cHM6Ly93d3cuZW50cnVzdC5uZXQvcnBhMAgGBmeB
# DAEEAjANBgkqhkiG9w0BAQ0FAAOCAgEAqat9vxoAhVvc7XEmXpSCr1yCS/ocOcVT
# tcMG3QNgfvlhmkEgwq5BFy6lQgiRCV6XMJiBRdaytYQ9i+mHB9oBP+AIWGcRIJQe
# wBaOY3e9m2wFjT21y5oxqUpcYjKiE86QnA3HkE9nw+Cof4eES9fywSEPEOcXufu9
# Ccy+iqYB/k2CT2kgmnVr5A33UCZT/DP3/huup2rAqOseryLTPWAVn7rk1SmktVef
# sWX2sUxh1dLI2resqhgfIBiKpvj1B/lyK/Zj2CWcFv77lN+GdKIgtPII3xbvOYB2
# OpKx0JaDatp8U4lZGw1c8bsp8iFPYSwkifh2CX/ZaJCOVwxk1XYAcVnz1ITIPKGI
# f6hv871uf7CojuaTbOkUxXUcDCvO8gf7ta7UQTG/wcxpmBiuWwiPq1xkuYRqvVw4
# od9PQrdLW1LT3vc7y59vwllCIk4LGLciyC/8agmF7VApUXrElEu2cWWKSoaaS3hL
# Voqh3i+Lk1syzKG576m2DNgGCxcwvw1vj5OsyxH18ccAntAZ15xfjlR8a6lDO2Pc
# wUSrvYw6Q/ByPySVzYSRXSEADXhrDVwjJJ9MrzTLFFreseRFUP2vb6cFgqdzz8/p
# kupzKrHh3aID5iC8HWcaVsIu9qxfyk6BsOZaHXPP0hTzUHgoBU4VboUk+DOoiK90
# bfRSzoyohJ4xggQaMIIEFgIBATBiME4xCzAJBgNVBAYTAlVTMRYwFAYDVQQKEw1F
# bnRydXN0LCBJbmMuMScwJQYDVQQDEx5FbnRydXN0IFRpbWUgU3RhbXBpbmcgQ0Eg
# LSBUUzICEFtwJsyW9ngau4X2EfVtu24wCwYJYIZIAWUDBAIDoIIBizAaBgkqhkiG
# 9w0BCQMxDQYLKoZIhvcNAQkQAQQwHAYJKoZIhvcNAQkFMQ8XDTI1MDEwOTAzMDYy
# OVowKwYJKoZIhvcNAQk0MR4wHDALBglghkgBZQMEAgOhDQYJKoZIhvcNAQENBQAw
# TwYJKoZIhvcNAQkEMUIEQJq/oy1hQTT3xdEF9FY7wbgiNK8o0n26N9KI4CUjBF0R
# LiLqXfE2YfoSA58rFBzaZBba5oS2hzfEd0jJBJOw9PgwgdAGCyqGSIb3DQEJEAIv
# MYHAMIG9MIG6MIG3MAsGCWCGSAFlAwQCAwRAORFCLhcCPqqZJJl0Dg7I6NJy01X8
# XPZs+RFWr5dVNOSAr9O8fExbV+/R/7zbdRRl4NQFWoVOmxE52ffsVdX+JDBmMFKk
# UDBOMQswCQYDVQQGEwJVUzEWMBQGA1UEChMNRW50cnVzdCwgSW5jLjEnMCUGA1UE
# AxMeRW50cnVzdCBUaW1lIFN0YW1waW5nIENBIC0gVFMyAhBbcCbMlvZ4GruF9hH1
# bbtuMA0GCSqGSIb3DQEBDQUABIICACUvQ2EtUpc6wdCis8N6ndoE1MQvk8rhJAhj
# uyTsf6bu7kcygr3S4G43Eq2dtdGwaGcas77koFVTeb0iDeXTXBbtsMDpEi9ePAhc
# crzZTb4PENZbiUaG8xG8P3ZQsW2TKEbCdiXnSx9iKmY2TN6Naov5P1895L7RMUTp
# JkA+NLwkFNcbFbm4AyQUUF9C/OYGz2Tgjyq2fkXswHlmulueKvdr8xaXDPah3aqf
# nkVEzUrPOzJUY0WWG/ZZbDuH5fBA91kJqj9RkF86ciQ2rz5X/ttPxCMT29nkbQpv
# 1fTtB7CmuRW3zezSmNOjhxL1UuJrzH6sNvjKc9G3dlktDsswPcj/hrH3T7E26K2I
# avQ26Ipf5wjoaQb3erDry2PtlJrs7w1xBEegchBFaVodBFnQE00j+DQ5CF5b5CvJ
# 3Z0/RLW41MnL+LpQzOl5u7hpZASem3Zi5KKwurOAjnFj7zwfOREKjjciGiJLJi1P
# LduyKPkTGljEXkD5Ms8ZR7Mkq6De+MAeNjSbTkcbxN3GcqcQJV7O5KJeediw3v+k
# PO6Qneck8Bq3bM2GJO79dPvk9CTv/HPsoafWkNQc5TR2rc8vYK5FY3cWuaG9fRnL
# VItEiW3GuXbEtX4JXgbqZ0Xu/Vr7IQaKvHLBM2pShh8kXSQIR21XtAJ4lQ3IwrnT
# HoRrP6CT
# SIG # End signature block
